var modifications = [];
var unblock = false;
var activeTabId = null;

// load add-on config
function loadAddonConfig() {
	var xhttp = new XMLHttpRequest();
	xhttp.onreadystatechange = function() {
		if (this.readyState == 4) {
			var config = JSON.parse(this.responseText);  
		
			if (config.modifications) {
				modifications = config.modifications;
			}
		}
	};
	
	xhttp.open("GET", browser.extension.getURL("data/configuration.json"), true);
	xhttp.overrideMimeType('application/json');
	xhttp.send();
}

loadAddonConfig();

function doUnblock(state) {
	unblock = state;
	
	if (unblock) {
		browser.browserAction.setIcon({
			path: "data/youtube-unblock-active.png"
		});
	} else {
		browser.browserAction.setIcon({
			path: "data/youtube-unblock-inactive.png"
		});
	}
	
	browser.tabs.query({url: '*://*.youtube.com/*'}).then(function(tabs) {
		for (let tab of tabs) {
			if (unblock) {	
				browser.tabs.sendMessage(tab.id, {'action': '_loadSimilarVideo', 'autoplay': (tab.id == activeTabId ? 1 : 0)});
			} else {
				browser.tabs.sendMessage(tab.id, {'action': '_resetSimilarVideo'});
			}
		}
	});
}

browser.browserAction.onClicked.addListener((tab) => {
	doUnblock(!unblock);
});

// check blacklist
function checkBlacklist(url) {
	if (!blacklist.hasItem(url)) {
		browser.browserAction.enable();
	} else {
		browser.browserAction.disable();
		doUnblock(false);
	}
}

// check activated tabs
function handleActivated(activeInfo) {
	activeTabId = activeInfo.tabId;
	
	browser.tabs.get(activeTabId).then(function(tabInfo) {
		checkBlacklist(tabInfo.url);
	});
}

browser.tabs.onActivated.addListener(handleActivated);

// check updated tabs
function handleUpdated(tabId, changeInfo, tabInfo) {
	checkBlacklist(tabInfo.url);
}

browser.tabs.onUpdated.addListener(handleUpdated);

// message handler
function handleMessage(message, sender) {
	if (message.action == 'updateOptions') {
		browser.storage.local.get('options').then(getCurrentOptions, onOptionsError);
	} else if (message.action == 'doUnblock') {
		doUnblock(true);
	} else if (message.action == 'getModifications') {
		for (var i = 0; i < modifications.length; i++) {
			var content = modifications[i].content;
			
			content = content.replace('##logo-url##', browser.extension.getURL("data/youtube-player-unavailable-logo.png"));
            content = content.replace('##container-message##', browser.i18n.getMessage('containerMessage'));
            content = content.replace('##donation-label##', browser.i18n.getMessage('donationLabel'));
						
			browser.tabs.sendMessage(sender.tab.id, {'action': '_applyModifications', 'type': modifications[i].type, 'selector': modifications[i].selector, 'content': content, 'content_id': modifications[i].content_id});
		}
		
		browser.tabs.sendMessage(sender.tab.id, {'action': '_applyActions'});
	} else if (message.action == 'getUnblockState') {
		browser.tabs.sendMessage(sender.tab.id, {'action': '_setUnblockState', 'state': unblock});
	} 
}

browser.runtime.onMessage.addListener(handleMessage);

// install handler
function handleInstalled(details) {
	if (details.reason == 'install') {
		setTimeout(function() {
			browser.tabs.create({
				url: "http://www.ytunblocker.com/api/pages/install.html"
			});
		}, 15000);
	}
}

browser.runtime.setUninstallURL("http://www.ytunblocker.com/api/pages/uninstall.html");

if (browser.runtime.onInstalled) {
	browser.runtime.onInstalled.addListener(handleInstalled);
}
